# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....command.v1 import set_dhw_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__dhw__setpoint__delta__pb2
from .....command.v1 import set_room_supply_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__room__supply__setpoint__delta__pb2
from .....command.v1 import set_room_temp_setpoint_delta_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__room__temp__setpoint__delta__pb2
from .....command.v1 import set_scheduled_heat_curve_deltas_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_set__scheduled__heat__curve__deltas__pb2
from .....state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9device/heat_pump/telemetry/v1/ccv/v1/telemetry_data.proto\x12$device.heat_pump.telemetry.v1.ccv.v1\x1a\x38\x64\x65vice/heat_pump/command/v1/set_dhw_setpoint_delta.proto\x1a@device/heat_pump/command/v1/set_room_supply_setpoint_delta.proto\x1a>device/heat_pump/command/v1/set_room_temp_setpoint_delta.proto\x1a\x41\x64\x65vice/heat_pump/command/v1/set_scheduled_heat_curve_deltas.proto\x1a%device/heat_pump/state/v1/state.proto\x1a\x1egoogle/protobuf/duration.proto\"\xcc\x07\n\x0cSensorValues\x12-\n outdoor_unit_ambient_temperature\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12,\n\x1foutdoor_unit_supply_temperature\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12,\n\x1foutdoor_unit_return_temperature\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x30\n#outdoor_unit_inner_coil_temperature\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12-\n indoor_unit_dhw_tank_temperature\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12+\n\x1eindoor_unit_supply_temperature\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x32\n%indoor_unit_supply_temperature_zone_1\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x32\n%indoor_unit_supply_temperature_zone_2\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x30\n#indoor_unit_room_temperature_zone_1\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x30\n#indoor_unit_room_temperature_zone_2\x18\n \x01(\x02H\t\x88\x01\x01\x12\x19\n\x0c\x66low_meter_1\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x19\n\x0c\x66low_meter_2\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x42#\n!_outdoor_unit_ambient_temperatureB\"\n _outdoor_unit_supply_temperatureB\"\n _outdoor_unit_return_temperatureB&\n$_outdoor_unit_inner_coil_temperatureB#\n!_indoor_unit_dhw_tank_temperatureB!\n\x1f_indoor_unit_supply_temperatureB(\n&_indoor_unit_supply_temperature_zone_1B(\n&_indoor_unit_supply_temperature_zone_2B&\n$_indoor_unit_room_temperature_zone_1B&\n$_indoor_unit_room_temperature_zone_2B\x0f\n\r_flow_meter_1B\x0f\n\r_flow_meter_2\"\xe5\x01\n\x13\x43\x61lculatedSetpoints\x12\x13\n\x06supply\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1a\n\rsupply_zone_1\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x1a\n\rsupply_zone_2\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x18\n\x0btemp_room_1\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x18\n\x0btemp_room_2\x18\x05 \x01(\x02H\x04\x88\x01\x01\x42\t\n\x07_supplyB\x10\n\x0e_supply_zone_1B\x10\n\x0e_supply_zone_2B\x0e\n\x0c_temp_room_1B\x0e\n\x0c_temp_room_2\"\x95\x05\n\x0bValveStatus\x12\x62\n\x19\x64hw_heating_cooling_valve\x18\x01 \x01(\x0e\x32:.device.heat_pump.telemetry.v1.ccv.v1.ValveStatus.PositionH\x00\x88\x01\x01\x12#\n\x16mixing_valve_1_opening\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12#\n\x16mixing_valve_2_opening\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12#\n\x16mixing_valve_1_closing\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12#\n\x16mixing_valve_2_closing\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12/\n\"mixing_valve_1_calculated_position\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12/\n\"mixing_valve_2_calculated_position\x18\x07 \x01(\x05H\x06\x88\x01\x01\"T\n\x08Position\x12\x18\n\x14POSITION_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOSITION_DHW\x10\x01\x12\x1c\n\x18POSITION_HEATING_COOLING\x10\x02\x42\x1c\n\x1a_dhw_heating_cooling_valveB\x19\n\x17_mixing_valve_1_openingB\x19\n\x17_mixing_valve_2_openingB\x19\n\x17_mixing_valve_1_closingB\x19\n\x17_mixing_valve_2_closingB%\n#_mixing_valve_1_calculated_positionB%\n#_mixing_valve_2_calculated_position\"\xce\x01\n\tSmartGrid\x12I\n\x05state\x18\x01 \x01(\x0e\x32\x35.device.heat_pump.telemetry.v1.ccv.v1.SmartGrid.StateH\x00\x88\x01\x01\"l\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_BLOCKED\x10\x01\x12\x10\n\x0cSTATE_NORMAL\x10\x02\x12\x14\n\x10STATE_ENCOURAGED\x10\x03\x12\x11\n\rSTATE_ORDERED\x10\x04\x42\x08\n\x06_state\"\xa2\x10\n\x0cMegmetStatus\x12\x1c\n\x0frequested_state\x18\x01 \x01(\rH\x00\x88\x01\x01\x12/\n\"compressor_need_percent_calculated\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x30\n#compressor_limit_percent_calculated\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12#\n\x16\x63urrent_operation_mode\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10\x61\x63_input_voltage\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x1d\n\x10\x61\x63_input_current\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\'\n\x1a\x63ompressor_frequency_limit\x18\x07 \x01(\rH\x06\x88\x01\x01\x12%\n\x18\x63ompressor_running_speed\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x1f\n\x12\x64\x63_fan_speed_limit\x18\t \x01(\rH\x08\x88\x01\x01\x12#\n\x16\x64\x63_fan_1_running_speed\x18\n \x01(\rH\t\x88\x01\x01\x12#\n\x16\x64\x63_fan_2_running_speed\x18\x0b \x01(\rH\n\x88\x01\x01\x12\x15\n\x08\x65\x65v_step\x18\x0c \x01(\rH\x0b\x88\x01\x01\x12\x1b\n\x0erelay_feedback\x18\r \x01(\rH\x0c\x88\x01\x01\x12 \n\x13\x61mbient_temperature\x18\x0e \x01(\x02H\r\x88\x01\x01\x12(\n\x1b\x65vaporator_coil_temperature\x18\x0f \x01(\x02H\x0e\x88\x01\x01\x12&\n\x19gas_discharge_temperature\x18\x10 \x01(\x02H\x0f\x88\x01\x01\x12#\n\x16gas_return_temperature\x18\x11 \x01(\x02H\x10\x88\x01\x01\x12\x1c\n\x0f\x63ompressor_code\x18\x12 \x01(\rH\x11\x88\x01\x01\x12$\n\x17outdoor_unit_dip_switch\x18\x13 \x01(\rH\x12\x88\x01\x01\x12 \n\x13\x65vaporator_pressure\x18\x14 \x01(\x02H\x13\x88\x01\x01\x12\x1f\n\x12\x63ondenser_pressure\x18\x15 \x01(\x02H\x14\x88\x01\x01\x12$\n\x17outdoor_unit_defrosting\x18\x16 \x01(\x08H\x15\x88\x01\x01\x12-\n outdoor_unit_pcb_program_version\x18\x17 \x01(\rH\x16\x88\x01\x01\x12,\n\x1foutdoor_unit_pcb_eeprom_version\x18\x18 \x01(\rH\x17\x88\x01\x01\x12+\n\x1emain_control_board_item_number\x18\x19 \x01(\rH\x18\x88\x01\x01\x12#\n\x16\x63ondensing_temperature\x18\x1a \x01(\x02H\x19\x88\x01\x01\x12$\n\x17\x65vaporating_temperature\x18\x1b \x01(\x02H\x1a\x88\x01\x01\x12$\n\x17inlet_water_temperature\x18\x1c \x01(\x02H\x1b\x88\x01\x01\x12%\n\x18outlet_water_temperature\x18\x1d \x01(\x02H\x1c\x88\x01\x01\x12#\n\x16inner_coil_temperature\x18\x1e \x01(\x02H\x1d\x88\x01\x01\x12\x1f\n\x12outdoor_unit_model\x18\x1f \x01(\tH\x1e\x88\x01\x01\x12\'\n\x1aoutdoor_unit_serial_number\x18  \x01(\tH\x1f\x88\x01\x01\x42\x12\n\x10_requested_stateB%\n#_compressor_need_percent_calculatedB&\n$_compressor_limit_percent_calculatedB\x19\n\x17_current_operation_modeB\x13\n\x11_ac_input_voltageB\x13\n\x11_ac_input_currentB\x1d\n\x1b_compressor_frequency_limitB\x1b\n\x19_compressor_running_speedB\x15\n\x13_dc_fan_speed_limitB\x19\n\x17_dc_fan_1_running_speedB\x19\n\x17_dc_fan_2_running_speedB\x0b\n\t_eev_stepB\x11\n\x0f_relay_feedbackB\x16\n\x14_ambient_temperatureB\x1e\n\x1c_evaporator_coil_temperatureB\x1c\n\x1a_gas_discharge_temperatureB\x19\n\x17_gas_return_temperatureB\x12\n\x10_compressor_codeB\x1a\n\x18_outdoor_unit_dip_switchB\x16\n\x14_evaporator_pressureB\x15\n\x13_condenser_pressureB\x1a\n\x18_outdoor_unit_defrostingB#\n!_outdoor_unit_pcb_program_versionB\"\n _outdoor_unit_pcb_eeprom_versionB!\n\x1f_main_control_board_item_numberB\x19\n\x17_condensing_temperatureB\x1a\n\x18_evaporating_temperatureB\x1a\n\x18_inlet_water_temperatureB\x1b\n\x19_outlet_water_temperatureB\x19\n\x17_inner_coil_temperatureB\x15\n\x13_outdoor_unit_modelB\x1d\n\x1b_outdoor_unit_serial_number\"\xa9\x05\n\x11\x45nergyCalculation\x12\'\n\x1a\x63urrent_electrical_power_w\x18\x01 \x01(\rH\x00\x88\x01\x01\x12&\n\x19\x65lectrical_energy_cum_kwh\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1c\n\x0f\x63urrent_phase_0\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x1c\n\x0f\x63urrent_phase_1\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x1c\n\x0f\x63urrent_phase_2\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x1c\n\x0fvoltage_phase_0\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x1c\n\x0fvoltage_phase_1\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x1c\n\x0fvoltage_phase_2\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12%\n\x18\x65lectrical_energy_cum_wh\x18\t \x01(\rH\x08\x88\x01\x01\x12!\n\x14water_energy_cum_kwh\x18\n \x01(\rH\t\x88\x01\x01\x12 \n\x13water_energy_cum_wh\x18\x0b \x01(\rH\n\x88\x01\x01\x12\x14\n\x07\x63op_now\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x42\x1d\n\x1b_current_electrical_power_wB\x1c\n\x1a_electrical_energy_cum_kwhB\x12\n\x10_current_phase_0B\x12\n\x10_current_phase_1B\x12\n\x10_current_phase_2B\x12\n\x10_voltage_phase_0B\x12\n\x10_voltage_phase_1B\x12\n\x10_voltage_phase_2B\x1b\n\x19_electrical_energy_cum_whB\x17\n\x15_water_energy_cum_kwhB\x16\n\x14_water_energy_cum_whB\n\n\x08_cop_now\"\xe4\x03\n\tFlowMeter\x12\"\n\x15num_pulses_per_minute\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04\x66low\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x42\n\x04type\x18\x03 \x01(\x0e\x32\x34.device.heat_pump.telemetry.v1.ccv.v1.FlowMeter.Type\x12#\n\x16\x61\x63\x63umulated_num_pulses\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12 \n\x13\x61\x63\x63umulated_flow_dl\x18\x05 \x01(\x04H\x03\x88\x01\x01\"\xbe\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12TYPE_NOT_CONNECTED\x10\x01\x12\x19\n\x15TYPE_HUBA_DN20_BRONZE\x10\x02\x12\x19\n\x15TYPE_HUBA_DN25_BRONZE\x10\x03\x12\x1a\n\x16TYPE_HUBA_DN20_PLASTIC\x10\x04\x12\x1a\n\x16TYPE_HUBA_DN25_PLASTIC\x10\x05\x12\x1a\n\x16TYPE_HUBA_DN10_PLASTIC\x10\x06\x42\x18\n\x16_num_pulses_per_minuteB\x07\n\x05_flowB\x19\n\x17_accumulated_num_pulsesB\x16\n\x14_accumulated_flow_dl\"\x9a\x01\n\nFlowMeters\x12\x45\n\x0c\x66low_meter_1\x18\x01 \x01(\x0b\x32/.device.heat_pump.telemetry.v1.ccv.v1.FlowMeter\x12\x45\n\x0c\x66low_meter_2\x18\x02 \x01(\x0b\x32/.device.heat_pump.telemetry.v1.ccv.v1.FlowMeter\"\x90\x02\n\x06Uptime\x12\x17\n\nccv_uptime\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12\x63ompressor_runtime\x18\x02 \x01(\rH\x01\x88\x01\x01\x12 \n\x13\x63ompressor_upstarts\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1b\n\x0euptime_restart\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\"\n\x15inline_heater_runtime\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\r\n\x0b_ccv_uptimeB\x15\n\x13_compressor_runtimeB\x16\n\x14_compressor_upstartsB\x11\n\x0f_uptime_restartB\x18\n\x16_inline_heater_runtime\"\xe7\x01\n\x0b\x43\x63vDateTime\x12\x11\n\x04year\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05month\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x10\n\x03\x64\x61y\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04hour\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x13\n\x06minute\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x13\n\x06second\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0b\x64\x61y_of_week\x18\x07 \x01(\rH\x06\x88\x01\x01\x42\x07\n\x05_yearB\x08\n\x06_monthB\x06\n\x04_dayB\x07\n\x05_hourB\t\n\x07_minuteB\t\n\x07_secondB\x0e\n\x0c_day_of_week\"\xbf\x01\n\x0f\x43\x63vSerialNumber\x12\x14\n\x07\x64igit_1\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07\x64igit_2\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x14\n\x07\x64igit_3\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x14\n\x07\x64igit_4\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07\x64igit_5\x18\x05 \x01(\x05H\x04\x88\x01\x01:\x02\x18\x01\x42\n\n\x08_digit_1B\n\n\x08_digit_2B\n\n\x08_digit_3B\n\n\x08_digit_4B\n\n\x08_digit_5\"f\n\nCcvVersion\x12\x12\n\x05major\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05minor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05patch\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_majorB\x08\n\x06_minorB\x08\n\x06_patch\"\x92\x03\n\x14\x45xternalSensorValues\x12\x16\n\tsource_18\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x16\n\tsource_19\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x16\n\tsource_20\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x16\n\tsource_21\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x16\n\tsource_22\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x16\n\tsource_23\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x16\n\tsource_24\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x16\n\tsource_25\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x16\n\tsource_26\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x16\n\tsource_27\x18\n \x01(\x02H\t\x88\x01\x01\x42\x0c\n\n_source_18B\x0c\n\n_source_19B\x0c\n\n_source_20B\x0c\n\n_source_21B\x0c\n\n_source_22B\x0c\n\n_source_23B\x0c\n\n_source_24B\x0c\n\n_source_25B\x0c\n\n_source_26B\x0c\n\n_source_27\"Y\n\x1b\x44omesticHotWaterBoostStatus\x12!\n\x14remaining_boost_time\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x17\n\x15_remaining_boost_time\"T\n\x0e\x41wayModeStatus\x12\x31\n\x0eremaining_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\"\xe9\x02\n\x0bHeatingMode\x12!\n\x10\x64\x65precated_state\x18\x01 \x01(\rB\x02\x18\x01H\x00\x88\x01\x01\x12$\n\x17\x61mbient_temp_avarage_1h\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12$\n\x17\x61mbient_temp_avarage_3h\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12%\n\x18\x61mbient_temp_avarage_24h\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x46\n\x0fpump_mode_state\x18\x05 \x01(\x0e\x32(.device.heat_pump.state.v1.PumpModeStateH\x04\x88\x01\x01\x42\x13\n\x11_deprecated_stateB\x1a\n\x18_ambient_temp_avarage_1hB\x1a\n\x18_ambient_temp_avarage_3hB\x1b\n\x19_ambient_temp_avarage_24hB\x12\n\x10_pump_mode_state\"h\n\x10\x43ompressorStatus\x12\x18\n\x0bspeed_level\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x19\n\x0cworking_mode\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0e\n\x0c_speed_levelB\x0f\n\r_working_mode\"\xb2\x02\n\x18SupplySetpointComponents\x12%\n\x18zone_1_heat_curve_output\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\'\n\x1azone_1_pi_regulator_output\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12%\n\x18zone_2_heat_curve_output\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\'\n\x1azone_2_pi_regulator_output\x18\x04 \x01(\x02H\x03\x88\x01\x01\x42\x1b\n\x19_zone_1_heat_curve_outputB\x1d\n\x1b_zone_1_pi_regulator_outputB\x1b\n\x19_zone_2_heat_curve_outputB\x1d\n\x1b_zone_2_pi_regulator_output\"x\n\x18RoomSupplySetpointDeltas\x12X\n\x1aroom_supply_setpoint_delta\x18\x01 \x03(\x0b\x32\x34.device.heat_pump.command.v1.RoomSupplySetpointDelta:\x02\x18\x01\"b\n\x11\x44hwSetpointDeltas\x12I\n\x12\x64hw_setpoint_delta\x18\x01 \x03(\x0b\x32-.device.heat_pump.command.v1.DhwSetpointDelta:\x02\x18\x01\"r\n\x16RoomTempSetpointDeltas\x12T\n\x18room_temp_setpoint_delta\x18\x01 \x03(\x0b\x32\x32.device.heat_pump.command.v1.RoomTempSetpointDelta:\x02\x18\x01\"z\n\x18ScheduledHeatCurveDeltas\x12Z\n\x1bscheduled_heat_curve_deltas\x18\x01 \x03(\x0b\x32\x35.device.heat_pump.command.v1.ScheduledHeatCurveDeltas:\x02\x18\x01\"\xcd\x01\n\x15\x43irculationPumpStatus\x12\x1a\n\rpump_0_active\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rpump_1_active\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1a\n\rpump_2_active\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0cpump_0_speed\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x10\n\x0e_pump_0_activeB\x10\n\x0e_pump_1_activeB\x10\n\x0e_pump_2_activeB\x0f\n\r_pump_0_speed\"\x98\x02\n\x12InlineHeaterStatus\x12\x16\n\tis_active\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12(\n\x1binline_heater_step_1_active\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12(\n\x1binline_heater_step_2_active\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12(\n\x1binline_heater_step_3_active\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x0c\n\n_is_activeB\x1e\n\x1c_inline_heater_step_1_activeB\x1e\n\x1c_inline_heater_step_2_activeB\x1e\n\x1c_inline_heater_step_3_active\"\xdd\x01\n\x1fOutdoorUnitSupplySwitchingValve\x12`\n\x08position\x18\x01 \x01(\x0e\x32N.device.heat_pump.telemetry.v1.ccv.v1.OutdoorUnitSupplySwitchingValve.Position\"T\n\x08Position\x12\x18\n\x14POSITION_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOSITION_DHW\x10\x01\x12\x1c\n\x18POSITION_HEATING_COOLING\x10\x02:\x02\x18\x01\"?\n\rEnergyBalance\x12\x1b\n\x0e\x65nergy_balance\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x11\n\x0f_energy_balance\"\xba\x01\n\x08UnitCode\x12\x19\n\x0corder_number\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0erunning_number\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0e\x61rticle_number\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08revision\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x0f\n\r_order_numberB\x11\n\x0f_running_numberB\x11\n\x0f_article_numberB\x0b\n\t_revision\"\x9c\x0e\n\x0eMegmetSettings\x12+\n\x1eworking_of_bottom_plate_heater\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x33\n&ambient_temp_bottom_plate_heater_start\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1c\n\x0fstop_hysteresis\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x41\n0deprecated_cooling_current_limit_compressor_stop\x18\x04 \x01(\rB\x02\x18\x01H\x03\x88\x01\x01\x12\x46\n5deprecated_cooling_current_limit_compressor_slow_down\x18\x05 \x01(\rB\x02\x18\x01H\x04\x88\x01\x01\x12\x44\n3deprecated_cooling_current_limit_compressor_release\x18\x06 \x01(\rB\x02\x18\x01H\x05\x88\x01\x01\x12\x41\n0deprecated_heating_current_limit_compressor_stop\x18\x07 \x01(\rB\x02\x18\x01H\x06\x88\x01\x01\x12\x46\n5deprecated_heating_current_limit_compressor_slow_down\x18\x08 \x01(\rB\x02\x18\x01H\x07\x88\x01\x01\x12\x44\n3deprecated_heating_current_limit_compressor_release\x18\t \x01(\rB\x02\x18\x01H\x08\x88\x01\x01\x12\x19\n\x0c\x64\x65\x66rost_mode\x18\n \x01(\rH\t\x88\x01\x01\x12\"\n\x15\x64\x65\x66rost_temperature_2\x18\x0b \x01(\rH\n\x88\x01\x01\x12\"\n\x15\x64\x65\x66rost_temperature_3\x18\x0c \x01(\rH\x0b\x88\x01\x01\x12\"\n\x15\x64\x65\x66rost_temperature_4\x18\r \x01(\rH\x0c\x88\x01\x01\x12\x32\n%cooling_current_limit_compressor_stop\x18\x0e \x01(\x02H\r\x88\x01\x01\x12\x37\n*cooling_current_limit_compressor_slow_down\x18\x0f \x01(\x02H\x0e\x88\x01\x01\x12\x35\n(cooling_current_limit_compressor_release\x18\x10 \x01(\x02H\x0f\x88\x01\x01\x12\x32\n%heating_current_limit_compressor_stop\x18\x11 \x01(\x02H\x10\x88\x01\x01\x12\x37\n*heating_current_limit_compressor_slow_down\x18\x12 \x01(\x02H\x11\x88\x01\x01\x12\x35\n(heating_current_limit_compressor_release\x18\x13 \x01(\x02H\x12\x88\x01\x01\x42!\n\x1f_working_of_bottom_plate_heaterB)\n\'_ambient_temp_bottom_plate_heater_startB\x12\n\x10_stop_hysteresisB3\n1_deprecated_cooling_current_limit_compressor_stopB8\n6_deprecated_cooling_current_limit_compressor_slow_downB6\n4_deprecated_cooling_current_limit_compressor_releaseB3\n1_deprecated_heating_current_limit_compressor_stopB8\n6_deprecated_heating_current_limit_compressor_slow_downB6\n4_deprecated_heating_current_limit_compressor_releaseB\x0f\n\r_defrost_modeB\x18\n\x16_defrost_temperature_2B\x18\n\x16_defrost_temperature_3B\x18\n\x16_defrost_temperature_4B(\n&_cooling_current_limit_compressor_stopB-\n+_cooling_current_limit_compressor_slow_downB+\n)_cooling_current_limit_compressor_releaseB(\n&_heating_current_limit_compressor_stopB-\n+_heating_current_limit_compressor_slow_downB+\n)_heating_current_limit_compressor_release\"\x93\n\n\rOperationData\x12%\n\x18uptime_ccv_since_restart\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x10uptime_ccv_total\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\'\n\x1aruntime_circulation_pump_0\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\'\n\x1aruntime_circulation_pump_1\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\'\n\x1aruntime_circulation_pump_2\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x1f\n\x12runtime_compressor\x18\x06 \x01(\rH\x05\x88\x01\x01\x12)\n\x1cruntime_inline_heater_step_1\x18\x07 \x01(\rH\x06\x88\x01\x01\x12)\n\x1cruntime_inline_heater_step_2\x18\x08 \x01(\rH\x07\x88\x01\x01\x12)\n\x1cruntime_inline_heater_step_3\x18\t \x01(\rH\x08\x88\x01\x01\x12\x17\n\nstarts_ccv\x18\n \x01(\rH\t\x88\x01\x01\x12&\n\x19starts_circulation_pump_0\x18\x0b \x01(\rH\n\x88\x01\x01\x12&\n\x19starts_circulation_pump_1\x18\x0c \x01(\rH\x0b\x88\x01\x01\x12&\n\x19starts_circulation_pump_2\x18\r \x01(\rH\x0c\x88\x01\x01\x12\x1e\n\x11starts_compressor\x18\x0e \x01(\rH\r\x88\x01\x01\x12(\n\x1bstarts_inline_heater_step_1\x18\x0f \x01(\rH\x0e\x88\x01\x01\x12(\n\x1bstarts_inline_heater_step_2\x18\x10 \x01(\rH\x0f\x88\x01\x01\x12(\n\x1bstarts_inline_heater_step_3\x18\x11 \x01(\rH\x10\x88\x01\x01\x12 \n\x13latest_reset_reason\x18\x12 \x01(\rH\x11\x88\x01\x01\x12+\n\x1elatest_reset_execution_context\x18\x13 \x01(\rH\x12\x88\x01\x01\x42\x1b\n\x19_uptime_ccv_since_restartB\x13\n\x11_uptime_ccv_totalB\x1d\n\x1b_runtime_circulation_pump_0B\x1d\n\x1b_runtime_circulation_pump_1B\x1d\n\x1b_runtime_circulation_pump_2B\x15\n\x13_runtime_compressorB\x1f\n\x1d_runtime_inline_heater_step_1B\x1f\n\x1d_runtime_inline_heater_step_2B\x1f\n\x1d_runtime_inline_heater_step_3B\r\n\x0b_starts_ccvB\x1c\n\x1a_starts_circulation_pump_0B\x1c\n\x1a_starts_circulation_pump_1B\x1c\n\x1a_starts_circulation_pump_2B\x14\n\x12_starts_compressorB\x1e\n\x1c_starts_inline_heater_step_1B\x1e\n\x1c_starts_inline_heater_step_2B\x1e\n\x1c_starts_inline_heater_step_3B\x16\n\x14_latest_reset_reasonB!\n\x1f_latest_reset_execution_context\"m\n\x11\x44hwControlSignals\x12\x1a\n\rstart_heating\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x19\n\x0cstop_heating\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x10\n\x0e_start_heatingB\x0f\n\r_stop_heating\"_\n\nLegionella\x12:\n\x12time_to_next_cycle\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x88\x01\x01\x42\x15\n\x13_time_to_next_cycle\"\xf5\x01\n\x03\x43op\x12?\n\x07heating\x18\x01 \x01(\x0b\x32..device.heat_pump.telemetry.v1.ccv.v1.Cop.Data\x12;\n\x03\x64hw\x18\x02 \x01(\x0b\x32..device.heat_pump.telemetry.v1.ccv.v1.Cop.Data\x1ap\n\x04\x44\x61ta\x12\x1b\n\x13\x61verage_input_power\x18\x01 \x01(\r\x12\x1b\n\x13\x61verage_output_heat\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_cop\x18\x03 \x01(\x02\x12\x19\n\x11number_of_samples\x18\x04 \x01(\r\"\xb5\x06\n\tScheduled\x12W\n\x18room_temp_setpoint_delta\x18\x01 \x01(\x0b\x32\x35.device.heat_pump.telemetry.v1.ccv.v1.Scheduled.Zones\x12$\n\x17\x64hw_temp_setpoint_delta\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12Y\n\x1aroom_supply_setpoint_delta\x18\x03 \x01(\x0b\x32\x35.device.heat_pump.telemetry.v1.ccv.v1.Scheduled.Zones\x12_\n\x11heat_curve_deltas\x18\x04 \x01(\x0b\x32\x44.device.heat_pump.telemetry.v1.ccv.v1.Scheduled.ZoneCurveSupplyDelta\x1aG\n\x05Zones\x12\x13\n\x06zone_1\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x13\n\x06zone_2\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\t\n\x07_zone_1B\t\n\x07_zone_2\x1a\x87\x03\n\x14ZoneCurveSupplyDelta\x12i\n\x06zone_1\x18\x01 \x01(\x0b\x32Y.device.heat_pump.telemetry.v1.ccv.v1.Scheduled.ZoneCurveSupplyDelta.HeatCurveSupplyDelta\x12i\n\x06zone_2\x18\x02 \x01(\x0b\x32Y.device.heat_pump.telemetry.v1.ccv.v1.Scheduled.ZoneCurveSupplyDelta.HeatCurveSupplyDelta\x1a\x98\x01\n\x14HeatCurveSupplyDelta\x12\x10\n\x03p_1\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03p_2\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x10\n\x03p_3\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x10\n\x03p_4\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x10\n\x03p_5\x18\x05 \x01(\x02H\x04\x88\x01\x01\x42\x06\n\x04_p_1B\x06\n\x04_p_2B\x06\n\x04_p_3B\x06\n\x04_p_4B\x06\n\x04_p_5B\x1a\n\x18_dhw_temp_setpoint_delta\"\xc0\x15\n\rTelemetryData\x12I\n\rsensor_values\x18\x01 \x01(\x0b\x32\x32.device.heat_pump.telemetry.v1.ccv.v1.SensorValues\x12S\n\x12\x65nergy_calculation\x18\x02 \x01(\x0b\x32\x37.device.heat_pump.telemetry.v1.ccv.v1.EnergyCalculation\x12L\n\tsetpoints\x18\x03 \x01(\x0b\x32\x39.device.heat_pump.telemetry.v1.ccv.v1.CalculatedSetpoints\x12I\n\rmegmet_status\x18\x04 \x01(\x0b\x32\x32.device.heat_pump.telemetry.v1.ccv.v1.MegmetStatus\x12R\n\x15\x64\x65precated_flow_meter\x18\x05 \x01(\x0b\x32/.device.heat_pump.telemetry.v1.ccv.v1.FlowMeterB\x02\x18\x01\x12K\n\x11\x64\x65precated_uptime\x18\x06 \x01(\x0b\x32,.device.heat_pump.telemetry.v1.ccv.v1.UptimeB\x02\x18\x01\x12H\n\rccv_date_time\x18\x07 \x01(\x0b\x32\x31.device.heat_pump.telemetry.v1.ccv.v1.CcvDateTime\x12_\n\x1c\x64\x65precated_ccv_serial_number\x18\x08 \x01(\x0b\x32\x35.device.heat_pump.telemetry.v1.ccv.v1.CcvSerialNumberB\x02\x18\x01\x12\x45\n\x0b\x63\x63v_version\x18\t \x01(\x0b\x32\x30.device.heat_pump.telemetry.v1.ccv.v1.CcvVersion\x12Z\n\x16\x65xternal_sensor_values\x18\n \x01(\x0b\x32:.device.heat_pump.telemetry.v1.ccv.v1.ExternalSensorValues\x12T\n\tdhw_boost\x18\x0b \x01(\x0b\x32\x41.device.heat_pump.telemetry.v1.ccv.v1.DomesticHotWaterBoostStatus\x12N\n\x10\x61way_mode_status\x18\x0c \x01(\x0b\x32\x34.device.heat_pump.telemetry.v1.ccv.v1.AwayModeStatus\x12G\n\x0cheating_mode\x18\r \x01(\x0b\x32\x31.device.heat_pump.telemetry.v1.ccv.v1.HeatingMode\x12Q\n\x11\x63ompressor_status\x18\x0e \x01(\x0b\x32\x36.device.heat_pump.telemetry.v1.ccv.v1.CompressorStatus\x12[\n\x13setpoint_components\x18\x10 \x01(\x0b\x32>.device.heat_pump.telemetry.v1.ccv.v1.SupplySetpointComponents\x12g\n\x1broom_supply_setpoint_deltas\x18\x11 \x01(\x0b\x32>.device.heat_pump.telemetry.v1.ccv.v1.RoomSupplySetpointDeltasB\x02\x18\x01\x12X\n\x13\x64hw_setpoint_deltas\x18\x12 \x01(\x0b\x32\x37.device.heat_pump.telemetry.v1.ccv.v1.DhwSetpointDeltasB\x02\x18\x01\x12\\\n\x17\x63irculation_pump_status\x18\x13 \x01(\x0b\x32;.device.heat_pump.telemetry.v1.ccv.v1.CirculationPumpStatus\x12V\n\x14inline_heater_status\x18\x14 \x01(\x0b\x32\x38.device.heat_pump.telemetry.v1.ccv.v1.InlineHeaterStatus\x12\x81\x01\n.deprecated_outdoor_unit_supply_switching_valve\x18\x15 \x01(\x0b\x32\x45.device.heat_pump.telemetry.v1.ccv.v1.OutdoorUnitSupplySwitchingValveB\x02\x18\x01\x12K\n\x0e\x65nergy_balance\x18\x16 \x01(\x0b\x32\x33.device.heat_pump.telemetry.v1.ccv.v1.EnergyBalance\x12G\n\x0cvalve_status\x18\x17 \x01(\x0b\x32\x31.device.heat_pump.telemetry.v1.ccv.v1.ValveStatus\x12\x43\n\nsmart_grid\x18\x18 \x01(\x0b\x32/.device.heat_pump.telemetry.v1.ccv.v1.SmartGrid\x12\x45\n\x0b\x66low_meters\x18\x19 \x01(\x0b\x32\x30.device.heat_pump.telemetry.v1.ccv.v1.FlowMeters\x12\x41\n\tunit_code\x18\x1a \x01(\x0b\x32..device.heat_pump.telemetry.v1.ccv.v1.UnitCode\x12M\n\x0fmegmet_settings\x18\x1b \x01(\x0b\x32\x34.device.heat_pump.telemetry.v1.ccv.v1.MegmetSettings\x12K\n\x0eoperation_data\x18\x1c \x01(\x0b\x32\x33.device.heat_pump.telemetry.v1.ccv.v1.OperationData\x12T\n\x13\x64hw_control_signals\x18\x1d \x01(\x0b\x32\x37.device.heat_pump.telemetry.v1.ccv.v1.DhwControlSignals\x12\x44\n\nlegionella\x18\x1e \x01(\x0b\x32\x30.device.heat_pump.telemetry.v1.ccv.v1.Legionella\x12\x36\n\x03\x63op\x18\x1f \x01(\x0b\x32).device.heat_pump.telemetry.v1.ccv.v1.Cop\x12\x63\n\x19room_temp_setpoint_deltas\x18  \x01(\x0b\x32<.device.heat_pump.telemetry.v1.ccv.v1.RoomTempSetpointDeltasB\x02\x18\x01\x12g\n\x1bscheduled_heat_curve_deltas\x18! \x01(\x0b\x32>.device.heat_pump.telemetry.v1.ccv.v1.ScheduledHeatCurveDeltasB\x02\x18\x01\x12\x42\n\tscheduled\x18\" \x01(\x0b\x32/.device.heat_pump.telemetry.v1.ccv.v1.ScheduledJ\x04\x08\x0f\x10\x10\x42\xff\x01\n6com.aira.contract.device.heat_pump.telemetry.v1.ccv.v1B\x12TelemetryDataProtoP\x01\xa2\x02\x05\x44HTVC\xaa\x02#Device.HeatPump.Telemetry.V1.Ccv.V1\xca\x02#Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\xe2\x02/Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\\GPBMetadata\xea\x02(Device::HeatPump::Telemetry::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.telemetry.v1.ccv.v1.telemetry_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6com.aira.contract.device.heat_pump.telemetry.v1.ccv.v1B\022TelemetryDataProtoP\001\242\002\005DHTVC\252\002#Device.HeatPump.Telemetry.V1.Ccv.V1\312\002#Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\342\002/Device\\HeatPump\\Telemetry\\V1\\Ccv\\V1\\GPBMetadata\352\002(Device::HeatPump::Telemetry::V1::Ccv::V1'
  _globals['_CCVSERIALNUMBER']._loaded_options = None
  _globals['_CCVSERIALNUMBER']._serialized_options = b'\030\001'
  _globals['_HEATINGMODE'].fields_by_name['deprecated_state']._loaded_options = None
  _globals['_HEATINGMODE'].fields_by_name['deprecated_state']._serialized_options = b'\030\001'
  _globals['_ROOMSUPPLYSETPOINTDELTAS']._loaded_options = None
  _globals['_ROOMSUPPLYSETPOINTDELTAS']._serialized_options = b'\030\001'
  _globals['_DHWSETPOINTDELTAS']._loaded_options = None
  _globals['_DHWSETPOINTDELTAS']._serialized_options = b'\030\001'
  _globals['_ROOMTEMPSETPOINTDELTAS']._loaded_options = None
  _globals['_ROOMTEMPSETPOINTDELTAS']._serialized_options = b'\030\001'
  _globals['_SCHEDULEDHEATCURVEDELTAS']._loaded_options = None
  _globals['_SCHEDULEDHEATCURVEDELTAS']._serialized_options = b'\030\001'
  _globals['_OUTDOORUNITSUPPLYSWITCHINGVALVE']._loaded_options = None
  _globals['_OUTDOORUNITSUPPLYSWITCHINGVALVE']._serialized_options = b'\030\001'
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_cooling_current_limit_compressor_stop']._loaded_options = None
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_cooling_current_limit_compressor_stop']._serialized_options = b'\030\001'
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_cooling_current_limit_compressor_slow_down']._loaded_options = None
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_cooling_current_limit_compressor_slow_down']._serialized_options = b'\030\001'
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_cooling_current_limit_compressor_release']._loaded_options = None
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_cooling_current_limit_compressor_release']._serialized_options = b'\030\001'
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_heating_current_limit_compressor_stop']._loaded_options = None
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_heating_current_limit_compressor_stop']._serialized_options = b'\030\001'
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_heating_current_limit_compressor_slow_down']._loaded_options = None
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_heating_current_limit_compressor_slow_down']._serialized_options = b'\030\001'
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_heating_current_limit_compressor_release']._loaded_options = None
  _globals['_MEGMETSETTINGS'].fields_by_name['deprecated_heating_current_limit_compressor_release']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_flow_meter']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_flow_meter']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_uptime']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_uptime']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_ccv_serial_number']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_ccv_serial_number']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['room_supply_setpoint_deltas']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['room_supply_setpoint_deltas']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['dhw_setpoint_deltas']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['dhw_setpoint_deltas']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_outdoor_unit_supply_switching_valve']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['deprecated_outdoor_unit_supply_switching_valve']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['room_temp_setpoint_deltas']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['room_temp_setpoint_deltas']._serialized_options = b'\030\001'
  _globals['_TELEMETRYDATA'].fields_by_name['scheduled_heat_curve_deltas']._loaded_options = None
  _globals['_TELEMETRYDATA'].fields_by_name['scheduled_heat_curve_deltas']._serialized_options = b'\030\001'
  _globals['_SENSORVALUES']._serialized_start=426
  _globals['_SENSORVALUES']._serialized_end=1398
  _globals['_CALCULATEDSETPOINTS']._serialized_start=1401
  _globals['_CALCULATEDSETPOINTS']._serialized_end=1630
  _globals['_VALVESTATUS']._serialized_start=1633
  _globals['_VALVESTATUS']._serialized_end=2294
  _globals['_VALVESTATUS_POSITION']._serialized_start=1994
  _globals['_VALVESTATUS_POSITION']._serialized_end=2078
  _globals['_SMARTGRID']._serialized_start=2297
  _globals['_SMARTGRID']._serialized_end=2503
  _globals['_SMARTGRID_STATE']._serialized_start=2385
  _globals['_SMARTGRID_STATE']._serialized_end=2493
  _globals['_MEGMETSTATUS']._serialized_start=2506
  _globals['_MEGMETSTATUS']._serialized_end=4588
  _globals['_ENERGYCALCULATION']._serialized_start=4591
  _globals['_ENERGYCALCULATION']._serialized_end=5272
  _globals['_FLOWMETER']._serialized_start=5275
  _globals['_FLOWMETER']._serialized_end=5759
  _globals['_FLOWMETER_TYPE']._serialized_start=5483
  _globals['_FLOWMETER_TYPE']._serialized_end=5673
  _globals['_FLOWMETERS']._serialized_start=5762
  _globals['_FLOWMETERS']._serialized_end=5916
  _globals['_UPTIME']._serialized_start=5919
  _globals['_UPTIME']._serialized_end=6191
  _globals['_CCVDATETIME']._serialized_start=6194
  _globals['_CCVDATETIME']._serialized_end=6425
  _globals['_CCVSERIALNUMBER']._serialized_start=6428
  _globals['_CCVSERIALNUMBER']._serialized_end=6619
  _globals['_CCVVERSION']._serialized_start=6621
  _globals['_CCVVERSION']._serialized_end=6723
  _globals['_EXTERNALSENSORVALUES']._serialized_start=6726
  _globals['_EXTERNALSENSORVALUES']._serialized_end=7128
  _globals['_DOMESTICHOTWATERBOOSTSTATUS']._serialized_start=7130
  _globals['_DOMESTICHOTWATERBOOSTSTATUS']._serialized_end=7219
  _globals['_AWAYMODESTATUS']._serialized_start=7221
  _globals['_AWAYMODESTATUS']._serialized_end=7305
  _globals['_HEATINGMODE']._serialized_start=7308
  _globals['_HEATINGMODE']._serialized_end=7669
  _globals['_COMPRESSORSTATUS']._serialized_start=7671
  _globals['_COMPRESSORSTATUS']._serialized_end=7775
  _globals['_SUPPLYSETPOINTCOMPONENTS']._serialized_start=7778
  _globals['_SUPPLYSETPOINTCOMPONENTS']._serialized_end=8084
  _globals['_ROOMSUPPLYSETPOINTDELTAS']._serialized_start=8086
  _globals['_ROOMSUPPLYSETPOINTDELTAS']._serialized_end=8206
  _globals['_DHWSETPOINTDELTAS']._serialized_start=8208
  _globals['_DHWSETPOINTDELTAS']._serialized_end=8306
  _globals['_ROOMTEMPSETPOINTDELTAS']._serialized_start=8308
  _globals['_ROOMTEMPSETPOINTDELTAS']._serialized_end=8422
  _globals['_SCHEDULEDHEATCURVEDELTAS']._serialized_start=8424
  _globals['_SCHEDULEDHEATCURVEDELTAS']._serialized_end=8546
  _globals['_CIRCULATIONPUMPSTATUS']._serialized_start=8549
  _globals['_CIRCULATIONPUMPSTATUS']._serialized_end=8754
  _globals['_INLINEHEATERSTATUS']._serialized_start=8757
  _globals['_INLINEHEATERSTATUS']._serialized_end=9037
  _globals['_OUTDOORUNITSUPPLYSWITCHINGVALVE']._serialized_start=9040
  _globals['_OUTDOORUNITSUPPLYSWITCHINGVALVE']._serialized_end=9261
  _globals['_OUTDOORUNITSUPPLYSWITCHINGVALVE_POSITION']._serialized_start=1994
  _globals['_OUTDOORUNITSUPPLYSWITCHINGVALVE_POSITION']._serialized_end=2078
  _globals['_ENERGYBALANCE']._serialized_start=9263
  _globals['_ENERGYBALANCE']._serialized_end=9326
  _globals['_UNITCODE']._serialized_start=9329
  _globals['_UNITCODE']._serialized_end=9515
  _globals['_MEGMETSETTINGS']._serialized_start=9518
  _globals['_MEGMETSETTINGS']._serialized_end=11338
  _globals['_OPERATIONDATA']._serialized_start=11341
  _globals['_OPERATIONDATA']._serialized_end=12640
  _globals['_DHWCONTROLSIGNALS']._serialized_start=12642
  _globals['_DHWCONTROLSIGNALS']._serialized_end=12751
  _globals['_LEGIONELLA']._serialized_start=12753
  _globals['_LEGIONELLA']._serialized_end=12848
  _globals['_COP']._serialized_start=12851
  _globals['_COP']._serialized_end=13096
  _globals['_COP_DATA']._serialized_start=12984
  _globals['_COP_DATA']._serialized_end=13096
  _globals['_SCHEDULED']._serialized_start=13099
  _globals['_SCHEDULED']._serialized_end=13920
  _globals['_SCHEDULED_ZONES']._serialized_start=13427
  _globals['_SCHEDULED_ZONES']._serialized_end=13498
  _globals['_SCHEDULED_ZONECURVESUPPLYDELTA']._serialized_start=13501
  _globals['_SCHEDULED_ZONECURVESUPPLYDELTA']._serialized_end=13892
  _globals['_SCHEDULED_ZONECURVESUPPLYDELTA_HEATCURVESUPPLYDELTA']._serialized_start=13740
  _globals['_SCHEDULED_ZONECURVESUPPLYDELTA_HEATCURVESUPPLYDELTA']._serialized_end=13892
  _globals['_TELEMETRYDATA']._serialized_start=13923
  _globals['_TELEMETRYDATA']._serialized_end=16675
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/v1/certificate.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/v1/certificate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64\x65vice/v1/certificate.proto\x12\tdevice.v1\"t\n\x0b\x43\x65rtificate\x12\x17\n\x0f\x63\x65rtificate_pem\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0f\x42t\n\x1b\x63om.aira.contract.device.v1B\x10\x43\x65rtificateProtoP\x01\xa2\x02\x03\x44XX\xaa\x02\tDevice.V1\xca\x02\tDevice\\V1\xe2\x02\x15\x44\x65vice\\V1\\GPBMetadata\xea\x02\nDevice::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.v1.certificate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.aira.contract.device.v1B\020CertificateProtoP\001\242\002\003DXX\252\002\tDevice.V1\312\002\tDevice\\V1\342\002\025Device\\V1\\GPBMetadata\352\002\nDevice::V1'
  _globals['_CERTIFICATE']._serialized_start=42
  _globals['_CERTIFICATE']._serialized_end=158
# @@protoc_insertion_point(module_scope)